.. include:: project-links.txt
.. include:: abbreviation.txt

.. _user-faq-page:

==========
 User FAQ
==========

KiCadRW FAQ
===========

How to get help or report an issue ?
------------------------------------

.. KiCadRW has a **Forum** hosted at https://kicad-rw.discourse.group

**If you encounter an issue, please file an issue** on the `Issue Tracker <https://github.com/FabriceSalvaire/KiCadRW/issues>`_.
